@@ -6,7 +6,7 @@ use poem_openapi::{
     payload::{Binary, Json, PlainText},
     registry::{MetaApi, MetaSchema},
     types::Type,
-    OpenApi, OpenApiService, ParseRequestError, Request, Response,
+    ApiRequest, ApiResponse, OpenApi, OpenApiService, ParseRequestError, Tags,
 };
 
 #[tokio::test]
@@ -51,26 +51,42 @@ fn deprecated() {
 
 #[test]
 fn tag() {
+    #[derive(Tags)]
+    enum MyTags {
+        /// User operations
+        UserOperations,
+        /// Pet operations
+        PetOperations,
+    }
+
     struct Api;
 
     #[OpenApi]
     impl Api {
-        #[oai(path = "/abc", method = "get", tag = "a", tag = "b")]
+        #[oai(
+            path = "/abc",
+            method = "get",
+            tag = "MyTags::UserOperations",
+            tag = "MyTags::PetOperations"
+        )]
         async fn test(&self) {}
     }
 
     let meta: MetaApi = Api::meta().remove(0);
-    assert_eq!(meta.paths[0].operations[0].tags, vec!["a", "b"]);
+    assert_eq!(
+        meta.paths[0].operations[0].tags,
+        vec!["user_operations", "pet_operations"]
+    );
 }
 
 #[tokio::test]
 async fn request() {
     /// Test request
-    #[derive(Request)]
+    #[derive(ApiRequest)]
     enum MyRequest {
         Json(Json<i32>),
-        PlainText(PlainText),
-        Binary(Binary),
+        PlainText(PlainText<String>),
+        Binary(Binary<Vec<u8>>),
     }
 
     struct Api;
@@ -153,7 +169,7 @@ async fn request() {
 
 #[tokio::test]
 async fn response() {
-    #[derive(Response)]
+    #[derive(ApiResponse)]
     enum MyResponse {
         /// Ok
         #[oai(status = 200)]
@@ -162,7 +178,7 @@ async fn response() {
         #[oai(status = 409)]
         AlreadyExists(Json<u16>),
         /// Default
-        Default(StatusCode, PlainText),
+        Default(StatusCode, PlainText<String>),
     }
 
     struct Api;
@@ -253,19 +269,19 @@ async fn response() {
 
 #[tokio::test]
 async fn bad_request_handler() {
-    #[derive(Response)]
+    #[derive(ApiResponse)]
     #[oai(bad_request_handler = "bad_request_handler")]
     enum MyResponse {
         /// Ok
         #[oai(status = 200)]
-        Ok(PlainText),
+        Ok(PlainText<String>),
         /// Already exists
         #[oai(status = 400)]
-        BadRequest(PlainText),
+        BadRequest(PlainText<String>),
     }
 
     fn bad_request_handler(err: ParseRequestError) -> MyResponse {
-        MyResponse::BadRequest(format!("!!! {}", err).into())
+        MyResponse::BadRequest(PlainText(format!("!!! {}", err)))
     }
 
     struct Api;
@@ -274,7 +290,7 @@ async fn bad_request_handler() {
     impl Api {
         #[oai(path = "/", method = "get")]
         async fn test(&self, #[oai(name = "code", in = "query")] code: u16) -> MyResponse {
-            MyResponse::Ok(format!("code: {}", code).into())
+            MyResponse::Ok(PlainText(format!("code: {}", code)))
         }
     }
 
